Print Summary (dalmatian)
# S3 method for dalmatian.summary
print(x, digits = 2, ...)Object of class dalamtion.summary created by summary.dalmatian().
Number of digits to display after decimal.
Ignored
No return value. This function prints the summary of a dalmatian object in a nicely formatted manner.
Bonner, S., Kim, H., Westneat, D., Mutzel, A.,
Wright, J., and Schofield, M.. (2021). dalmatian: A Package
for Fitting Double Hierarchical Linear Models in R via JAGS and
nimble. Journal of Statistical Software, 100, 10, 1--25.
10.18637/jss.v100.i10.